@@ -3,7 +3,7 @@
 #' @export
 #' @importFrom lsa cosine
 
-pairwise <- function(x,y,tvectors=tvectors,breakdown=FALSE){
+pairwise <- function(x,y,tvectors=tvectors){
   
   if(is.data.frame(tvectors)){
     tvectors <- as.matrix(tvectors)
@@ -41,10 +41,6 @@ pairwise <- function(x,y,tvectors=tvectors,breakdown=FALSE){
     y[which(!(y %in% rownames(tvectors)))] <- NA
     
     
-    if(breakdown==TRUE){x <- breakdown(x)
-                        y <- breakdown(y)}
-    
-    
     vecs1                    <- matrix(nrow=length(x),ncol=ncol(tvectors))
     vecs1[which(!is.na(x)),] <- tvectors[x[!is.na(x)],]
     
